from base_st_classes import *

class LookuppSuite(NFSSuite):
    """Test operation 16: LOOKUPP

    Equivalence partitioning:
        
    Input Condition: current filehandle
        Valid equivalence classes:
            directory(10)
            named attribute dir(11)
        Invalid equivalence classes:
            not directory(12)
            invalid filehandle(13)

    """
    #
    # Testcases covering valid equivalence classes.
    #
    def testDir(self):
        """LOOKUPP with directory (cfh)

        Covered valid equivalence classes: 10
        """
        ops = [self.ncl.putrootfh_op()] + self.ncl.lookup_path(self.docporting)
        ops.append(self.ncl.lookupp_op())
        ops.append(self.ncl.lookup_op("README"))
        res = self.ncl.do_ops(ops)
        self.assert_OK(res)

    def testNamedAttrDir(self):
        """LOOKUPP with named attribute directory (cfh)

        Covered valid equivalence classes: 11

        Comments: Not yet implemented. 
        """
        # FIXME: Implement.
        self.skip("(TEST NOT IMPLEMENTED)")

    #
    # Testcases covering invalid equivalence classes.
    #
    def testInvalidFh(self):
        """LOOKUPP with non-dir (cfh)

        Covered invalid equivalence classes: 12
        """
        ops = [self.ncl.putrootfh_op()] + self.ncl.lookup_path(self.regfile)
        ops.append(self.ncl.lookupp_op())
        res = self.ncl.do_ops(ops)
        self.assert_status(res, [NFS4ERR_NOTDIR])

    #
    # Extra tests.
    #
    def testAtRoot(self):
        """LOOKUPP with (cfh) at root should return NFS4ERR_NOENT

        Extra test
        """
        lookuppop = self.ncl.lookupp_op()
        res = self.ncl.do_ops([self.ncl.putrootfh_op(), lookuppop])
        self.assert_status(res, [NFS4ERR_NOENT])

    def testNoCfh(self):
        """LOOKUPP with no (cfh) should return NFS4ERR_NOFILEHANDLE
        """
        res = self.ncl.do_ops([self.ncl.lookupp_op()])
        self.assert_status(res,[NFS4ERR_NOFILEHANDLE])
